@@ -4,7 +4,7 @@
 					with fkt (fast kernel tracing) in the kernel.
 
 	Copyright (C) 2000, 2001  Robert D. Russell -- rdr@unh.edu
-				  2003, 2004  Samuel Thibault -- samuel.thibault@ens-lyon.org
+	2003, 2004, 2012  Samuel Thibault -- samuel.thibault@ens-lyon.org
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -72,7 +72,7 @@ struct code_list_item	{
 void dumptime( char *message , time_t *the_time, clock_t *the_jiffies )
 	{
 	struct tms		cur_time;
-	struct tm		breakout;
+	struct tm		*breakout;
 	char			buffer[128];
 
 	if( (*the_time = time(NULL)) == -1 )
@@ -81,10 +81,10 @@ void dumptime( char *message , time_t *the_time, clock_t *the_jiffies )
 	if( (*the_jiffies = times(&cur_time)) == (clock_t) -1 )
 		perror("times");
 
-	if( localtime_r(the_time, &breakout) == NULL )
+	if( (breakout = localtime(the_time)) == NULL )
 		fprintf(stderr, "Unable to break out current time\n");
 
-	if( strftime(buffer, 128, "%d-%b-%Y %H:%M:%S", &breakout) == 0 )
+	if( strftime(buffer, 128, "%d-%b-%Y %H:%M:%S", breakout) == 0 )
 		fprintf(stderr, "Unable to convert current time\n");
 
 	printf("%7s: %s: user_time = %ld, system_time = %ld, jiffies = %ld\n",
